@@ -1,8 +1,8 @@
 use pacman_bintrans_common::errors::*;
 use pacman_bintrans_common::http::Proxy;
 use std::path::PathBuf;
-use structopt::StructOpt;
 use structopt::clap::AppSettings;
+use structopt::StructOpt;
 use url::Url;
 
 #[derive(Debug, StructOpt)]
@@ -23,10 +23,13 @@ pub struct Args {
     /// Only use the proxy for transparency signatures, not the pkg
     #[structopt(long)]
     pub bypass_proxy_for_pkgs: bool,
+    #[structopt(long = "rebuilder")]
+    pub rebuilders: Vec<Url>,
+    #[structopt(long, default_value = "0")]
+    pub required_rebuild_confirms: usize,
     pub url: Url,
 }
 
 fn parse_proxy(proxy: &str) -> Result<Proxy> {
-    Proxy::all(proxy)
-        .map_err(Error::from)
+    Proxy::all(proxy).map_err(Error::from)
 }
